<?php
$TRANSLATIONS = array(
"Could not load template" => "Kon sjabloon niet laden",
"Saved" => "Bewaard",
"Reset" => "Reset",
"An error occurred" => "Er heeft zich een fout voorgedaan",
"Sharing email - public link shares (HTML)" => "Delen e-mail - openbare links delen (HTML)",
"Sharing email - public link shares (plain text fallback)" => "Delen e-mail - openbare links delen (terugval op kale tekst)",
"Sharing email (HTML)" => "Delen e-mail (HTML)",
"Sharing email (plain text fallback)" => "Delen e-mail (terugvallen op kale tekst)",
"Lost password mail" => "Vergeten wachtwoord e-mail",
"New user email (HTML)" => "Nieuwe gebruiker e-mail (HTML)",
"New user email (plain text fallback)" => "Nieuwe gebruiker e-mail (platte tekst terugval)",
"Activity notification mail" => "Activiteitenmelding e-mail",
"Mail Templates" => "E-mailsjablonen",
"Theme" => "Thema",
"Template" => "Sjabloon",
"Please choose a template" => "Kies een sjabloon",
"Save" => "Bewaren"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
